hist.axis package
=================

Submodules
----------

hist.axis.transform module
--------------------------

.. automodule:: hist.axis.transform
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hist.axis
   :members:
   :undoc-members:
   :show-inheritance:
